@@ -1,29 +1,20 @@
-from typing import TYPE_CHECKING, Any, Literal, Union
+from typing import TYPE_CHECKING, Any, Union
 
 from litestar.di import Provide
 from litestar.plugins import InitPluginProtocol
 
-from sqlspec.base import (
-    AsyncConfigT,
-    ConnectionT,
-    DatabaseConfigProtocol,
-    PoolT,
-    SyncConfigT,
-)
 from sqlspec.base import SQLSpec as SQLSpecBase
+from sqlspec.config import AsyncConfigT, DatabaseConfigProtocol, DriverT, SyncConfigT
 from sqlspec.exceptions import ImproperConfigurationError
 from sqlspec.extensions.litestar.config import DatabaseConfig
+from sqlspec.typing import ConnectionT, PoolT
+from sqlspec.utils.logging import get_logger
 
 if TYPE_CHECKING:
     from click import Group
     from litestar.config.app import AppConfig
 
-
-CommitMode = Literal["manual", "autocommit", "autocommit_include_redirect"]
-DEFAULT_COMMIT_MODE: CommitMode = "manual"
-DEFAULT_CONNECTION_KEY = "db_connection"
-DEFAULT_POOL_KEY = "db_pool"
-DEFAULT_SESSION_KEY = "db_session"
+logger = get_logger("extensions.litestar")
 
 
 class SQLSpec(InitPluginProtocol, SQLSpecBase):
@@ -31,10 +22,7 @@ class SQLSpec(InitPluginProtocol, SQLSpecBase):
 
     __slots__ = ("_config", "_plugin_configs")
 
-    def __init__(
-        self,
-        config: Union["SyncConfigT", "AsyncConfigT", "DatabaseConfig", list["DatabaseConfig"]],
-    ) -> None:
+    def __init__(self, config: Union["SyncConfigT", "AsyncConfigT", "DatabaseConfig", list["DatabaseConfig"]]) -> None:
         """Initialize ``SQLSpecPlugin``.
 
         Args:
@@ -69,20 +57,32 @@ class SQLSpec(InitPluginProtocol, SQLSpecBase):
         Returns:
             The updated :class:`AppConfig <.config.app.AppConfig>` instance.
         """
+
         self._validate_dependency_keys()
+
+        def store_sqlspec_in_state() -> None:
+            app_config.state.sqlspec = self
+
+        app_config.on_startup.append(store_sqlspec_in_state)
+        # Register types for injection
         app_config.signature_types.extend(
-            [
-                SQLSpec,
-                ConnectionT,
-                PoolT,
-                DatabaseConfig,
-                DatabaseConfigProtocol,
-                SyncConfigT,
-                AsyncConfigT,
-            ]
+            [SQLSpec, ConnectionT, PoolT, DriverT, DatabaseConfig, DatabaseConfigProtocol, SyncConfigT, AsyncConfigT]
         )
+
+        # Create signature namespace for connection types
+        signature_namespace = {}
+
         for c in self._plugin_configs:
             c.annotation = self.add_config(c.config)
+            app_config.signature_types.append(c.annotation)
+            app_config.signature_types.append(c.config.connection_type)  # type: ignore[union-attr]
+            app_config.signature_types.append(c.config.driver_type)  # type: ignore[union-attr]
+
+            # Get signature namespace from the config
+            if hasattr(c.config, "get_signature_namespace"):
+                config_namespace = c.config.get_signature_namespace()  # type: ignore[attr-defined]
+                signature_namespace.update(config_namespace)
+
             app_config.before_send.append(c.before_send_handler)
             app_config.lifespan.append(c.lifespan_handler)  # pyright: ignore[reportUnknownMemberType]
             app_config.dependencies.update(
@@ -90,9 +90,13 @@ class SQLSpec(InitPluginProtocol, SQLSpecBase):
                     c.connection_key: Provide(c.connection_provider),
                     c.pool_key: Provide(c.pool_provider),
                     c.session_key: Provide(c.session_provider),
-                },
+                }
             )
 
+        # Update app config with signature namespace
+        if signature_namespace:
+            app_config.signature_namespace.update(signature_namespace)
+
         return app_config
 
     def get_annotations(self) -> "list[type[Union[SyncConfigT, AsyncConfigT]]]":  # pyright: ignore[reportInvalidTypeVarUse]
@@ -104,8 +108,7 @@ class SQLSpec(InitPluginProtocol, SQLSpecBase):
         return [c.annotation for c in self.config]
 
     def get_annotation(
-        self,
-        key: "Union[str, SyncConfigT, AsyncConfigT, type[Union[SyncConfigT, AsyncConfigT]]]",
+        self, key: "Union[str, SyncConfigT, AsyncConfigT, type[Union[SyncConfigT, AsyncConfigT]]]"
     ) -> "type[Union[SyncConfigT, AsyncConfigT]]":
         """Return the annotation for the given configuration.
 
