@@ -55,7 +55,7 @@ def on_warn_missing_reference(app: "Sphinx", domain: str, node: Node) -> "Option
     if not hasattr(node, "attributes"):
         return None
 
-    attributes = node.attributes  # type: ignore[attr-defined]
+    attributes = node.attributes
     target = cast("str", attributes["reftarget"])
 
     if reference_target_source_obj := cast(
@@ -93,15 +93,12 @@ def on_warn_missing_reference(app: "Sphinx", domain: str, node: Node) -> "Option
 
 
 def on_missing_reference(
-    app: "Sphinx",
-    env: "BuildEnvironment",
-    node: "pending_xref",
-    contnode: "Element",
+    app: "Sphinx", env: "BuildEnvironment", node: "pending_xref", contnode: "Element"
 ) -> "Optional[Element]":
     if not hasattr(node, "attributes"):
         return None
 
-    attributes = node.attributes  # type: ignore[attr-defined]
+    attributes = node.attributes
     target = attributes["reftarget"]
     py_domain = env.domains["py"]
 
